import { Component } from "@angular/core";
import { PageBase } from "src/app/core/base/page-base";
import { ToastService } from "src/app/service/toast.service";
import { ConfirmationDialogService } from "src/app/service/confirmation-dialog.service";
import { PermissionsEnum } from "src/app/model/auth/permissionsEnum";
import { ShortUrl } from "src/app/model/entities/short-url";
import { ShortUrlsDataService } from "src/app/modules/admin/short-urls/short-urls.data.service";
import { ShortUrlsColumns } from "src/app/modules/admin/short-urls/short-urls.columns";

@Component({
  selector: "app-short-urls",
  templateUrl: "./short-urls.page.html",
  styleUrl: "./short-urls.page.scss",
})
export class ShortUrlsPage extends PageBase<
  ShortUrl,
  ShortUrlsDataService,
  ShortUrlsColumns
> {
  constructor(
    private toast: ToastService,
    private confirmation: ConfirmationDialogService,
  ) {
    super(true, {
      read: [PermissionsEnum.shortUrls],
      create: [PermissionsEnum.shortUrlsCreate],
      update: [PermissionsEnum.shortUrlsUpdate],
      delete: [PermissionsEnum.shortUrlsDelete],
      restore: [PermissionsEnum.shortUrlsDelete],
    });
  }

  load(): void {
    this.loading = true;
    this.dataService
      .load(this.filter, this.sort, this.skip, this.take)
      .subscribe((result) => {
        this.result = result;
        this.loading = false;
      });
  }

  delete(group: ShortUrl): void {
    this.confirmation.confirmDialog({
      header: "dialog.delete.header",
      message: "dialog.delete.message",
      accept: () => {
        this.loading = true;
        this.dataService.delete(group).subscribe(() => {
          this.toast.success("action.deleted");
          this.load();
        });
      },
      messageParams: { entity: group.shortUrl },
    });
  }

  restore(group: ShortUrl): void {
    this.confirmation.confirmDialog({
      header: "dialog.restore.header",
      message: "dialog.restore.message",
      accept: () => {
        this.loading = true;
        this.dataService.restore(group).subscribe(() => {
          this.toast.success("action.restored");
          this.load();
        });
      },
      messageParams: { entity: group.shortUrl },
    });
  }
}
